@@ -11,7 +11,8 @@ use Clustericious::Log;
 use Mojo::URL;
 use Scalar::Util qw( weaken );
 use Mojo::Base 'Mojolicious';
-use File::HomeDir ();
+use File::Glob qw( bsd_glob );
+use File::Path qw( mkpath );
 use Carp qw( croak carp );
 use Clustericious;
 use Clustericious::Controller;
@@ -20,7 +21,7 @@ use Clustericious::Commands;
 use Path::Class::Dir;
 
 # ABSTRACT: Clustericious app base class
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.25'; # VERSION
 
 
 has commands => sub {
@@ -119,6 +120,13 @@ sub dump_api_table
 }
 
 
+sub _my_dist_data
+{
+  my $dir = bsd_glob '~/.local/share/Perl/dist/Clustericious';
+  mkpath $dir, 0, 0700;
+  $dir;
+}
+
 sub config
 {
   my($self, $what) = @_;
@@ -140,7 +148,7 @@ sub config
         default => sub {
           my $url = Mojo::URL->new($config->{url});
           {
-            pid_file => File::Spec->catfile( File::HomeDir->my_dist_data("Clustericious", { create => 1 } ), 'hypnotoad-' . $url->port . '-' . $url->host . '.pid' ),
+            pid_file => File::Spec->catfile( _my_dist_data(), 'hypnotoad-' . $url->port . '-' . $url->host . '.pid' ),
             listen => [
               $url->to_string,
             ],
@@ -184,7 +192,7 @@ Clustericious::App - Clustericious app base class
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
